/*
 * lefCmd.c --
 *
 * Commands for the LEF module only.
 *
 */

#ifndef lint
static char rcsid[] = "$Header: /ufs/repository/magic/lef/lefCmd.c,v 1.0 2003/05/01 10:54:00 tim Exp $";
#endif  /* not lint */

#include <stdio.h>
#include <stdlib.h>
#ifdef SYSV
#include <string.h>
#endif

#include "magic/tclmagic.h"
#include "misc/magic.h"
#include "utils/geometry.h"
#include "tiles/tile.h"
#include "utils/hash.h"
#include "database/database.h"
#include "windows/windows.h"
#include "dbwind/dbwind.h"
#include "main/main.h"
#include "textio/txcommands.h"
#include "commands/commands.h"


/*
 * ----------------------------------------------------------------------------
 *
 * CmdLef --
 *
 * Implement the "lef" command:  generate LEF-format output for a layout
 *
 * Usage:
 *	lef [options]
 *
 * Results:
 *	None.
 *
 * Side effects:
 *	Generates LEF-format output on disk somewhere.
 *
 * ----------------------------------------------------------------------------
 */

/* These definitions must correspond to the ordering in cmdLefOption[] below */

#define LEF_WRITE		0
#define LEF_WRITEALL		1
#define LEF_HELP		2

Void
CmdLef(w, cmd)
    MagWindow *w;
    TxCommand *cmd;
{
    int option;
    char **msg, *namep;
    CellUse *selectedUse;
    CellDef *selectedDef;

    static char *cmdLefOption[] =
    {	
	"write [cell]		write current or indicated cell",
	"writeall		write all cells from the top-level cell",
	"help                   print this help information",
	NULL
    };

    if (cmd->tx_argc < 2)
	option = LEF_HELP;
    else
    {
	option = Lookup(cmd->tx_argv[1], cmdLefOption);
	if (option < 0)
	{
	    TxError("\"%s\" isn't a valid LEF option.\n", cmd->tx_argv[1]);
	    option = LEF_HELP;
	}
    }

    if (option != LEF_HELP)
    {
        windCheckOnlyWindow(&w, DBWclientID);
        if (w == (MagWindow *) NULL)
        {
            if (ToolGetBox(&selectedDef,NULL) == FALSE)
            {
                TxError("Point to a window first\n");
                return;
            }
            selectedUse = selectedDef->cd_parents;
        }
        else
        {
            selectedUse = (CellUse *)w->w_surfaceID;
        }
    }

    switch (option)
    {
	case LEF_WRITEALL:
	    LefWriteAll(selectedUse);
	    break;
	case LEF_WRITE:
            if (cmd->tx_argc != 3) goto wrongNumArgs;
            namep = cmd->tx_argv[2];
            selectedUse = CmdGetSelectedCell((Transform *) NULL);
            if (selectedUse == NULL)
            {
                TxError("No cell selected\n");
                return;
            }
            LefWriteCell(selectedUse->cu_def, namep, selectedUse->cu_def
		== EditRootDef);
	    break;
	case LEF_HELP:
wrongNumArgs:
	    TxPrintf("The \"lef\" options are:\n");
	    for (msg = &(cmdLefOption[0]); *msg != NULL; msg++)
	    {
		TxPrintf("    lef %s\n", *msg);
	    }
	    break;
    }
}
